function [priormean,Priorcovariance]=build_soe_minn(p,exogenous,q,var_order,scales,lambdas,difference,firstlagmean,domesticdummies,IncludeConstant,PriorSeason,SeasonalVars)

NumberOfExoInPi=0;
endogenous=setdiff(1:p,exogenous);
% First for B'=[PI_{1},...,PI_{var_order},PHI]
if IncludeConstant==1 % Constant on standard form
    Stds=cell(var_order+1,1); % Adding a lag more than the lag order for the deterministic trends.
else % Constant on mean adjusted form
    Stds=cell(var_order,1);
end

for k=1:var_order
    Stds{k}=zeros(p,p);
    
    % Special handling of lags at seasonal frequency and the lag after lags
    % at seasonal frequency (lag 4,5,8,9,12,13, ... for quarterly data)
    if k>1 & PriorSeason>0 
        switch rem(k,PriorSeason)
            case 0 % Lag is seasonal lag
                SeasonAdj=PriorSeason;
                SeasonImportance=lambdas(6);
            case 1        
                SeasonAdj=(1/2)*(PriorSeason+1);
                SeasonImportance=lambdas(6);
            otherwise
                SeasonAdj=1;
                SeasonImportance=1;
        end
    else
        SeasonAdj=1;
        SeasonImportance=1;
    end
    for i=1:p
        for j=1:p
            if (i==j)*sum(SeasonalVars==i) % Variable i and is a seasonal variable. 
                SeasonImportanceDynamic=SeasonImportance;
                SeasonAdjDynamic=SeasonAdj;
            else
                SeasonImportanceDynamic=1;
                SeasonAdjDynamic=1;
            end
            Stds{k}(i,j)=lambdas(1)*lambdas(2)*SeasonImportanceDynamic*scales(i)/((k/SeasonAdjDynamic)^(lambdas(3))*scales(j));
        end
        Stds{k}(i,i)=(1/lambdas(2))*Stds{k}(i,i); % removing the cross-equation shrinkage on own lags
    end
    Stds{k}(exogenous,endogenous)=lambdas(4)*Stds{k}(exogenous,endogenous);
end

if IncludeConstant==1
    Stds{var_order+1}=ones(p,q)*lambdas(5);
    if isempty(exogenous)
        domesticdummies=[];
    end
    Stds{var_order+1}(exogenous,domesticdummies)=lambdas(4)*Stds{var_order+1}(exogenous,domesticdummies);
    NumberOfExoInPi=q;
end

% Stds is the prior standard deviations for B'=[Pi_{1},...,P_{var_order} Theta]. The following operations transform to a prior on B.
Temp=[];
for k=1:length(Stds)
    Temp=[Temp Stds{k}];
end
Temp=Temp';
Priorcovariance=diag(Temp(:)).^2;


% If firstlagmean is non-empty, the prior mean of (the diagonal of) the
% first VAR lag is changed from the Minnesota choice to the vector
% firstlagmean.
if ~isempty(firstlagmean)
    Firstlagmean=diag(firstlagmean);
else
    Firstlagmean=eye(p);
    % Varibles in growth rates have mean zero on first lag coeff.
    for i=1:length(difference)
        Firstlagmean(difference(i),difference(i))=0;
    end
end


priormean=[Firstlagmean zeros(p,p*(var_order-1)+NumberOfExoInPi)]';
priormean=priormean(:);
